ToSmall

Trait ToSmall 

pub trait ToSmall: ToMini { }
👎Deprecated since 1.23.0:

ToMini instead

Types implementing this trait can be converted to SmallFloat.

The following are implemented when T implements ToSmall:

This trait is sealed and cannot be implemented for more types; it is implemented for bool, for the integer types i8, i16, i32, i64, i128, isize, u8, u16, u32, u64, u128 and usize, and for the floating-point types f32 and f64.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T: ToMini> ToSmall for T