pub enum Order {
Lsf,
LsfLe,
LsfBe,
Msf,
MsfLe,
MsfBe,
}Expand description
The ordering of digits inside a slice, and bytes inside a digit.
Examples
use rug::integer::Order;
use rug::Integer;
let i = Integer::from(0x0102_0304);
let mut buf: [u16; 4] = [0; 4];
// most significant 16-bit digit first, little endian digits
i.write_digits(&mut buf, Order::MsfLe);
assert_eq!(buf, [0, 0, 0x0102u16.to_le(), 0x0304u16.to_le()]);
// least significant 16-bit digit first, big endian digits
i.write_digits(&mut buf, Order::LsfBe);
assert_eq!(buf, [0x0304u16.to_be(), 0x0102u16.to_be(), 0, 0]);Variants
Lsf
Least significant digit first, with each digit in the target’s endianness.
LsfLe
Least significant digit first, with little endian digits.
LsfBe
Least significant digit first, with big endian digits.
Msf
Most significant digit first, with each digit in the target’s endianness.
MsfLe
Most significant digit first, with little endian digits.
MsfBe
Most significant digit first, with big endian digits.